# Learning Guide

The detailed learning-oriented documentation now lives under [`docs/`](./docs/README.md).

Recommended starting points:

- [Progress](./docs/progress.md)
- [How It Works](./docs/how-it-works.md)
- [Architecture](./docs/architecture.md)
- [Improvement Roadmap](./docs/improvement-roadmap.md)
- [Research Inspiration](./docs/research-inspiration.md)
